@@ -29,6 +29,7 @@ NO_BREAK_SEQUENCES = [
     "а",
     "без",
     "в",
+    "во",
     "где",
     "для",
     "же",
@@ -50,6 +51,7 @@ NO_BREAK_SEQUENCES = [
     "под",
     "при",
     "с",
+    "со",
     "то",
     "у",
     "что",
